/*
QmidiNet - A MIDI Network Gateway via UDP/IP Multicast

   Copyright (C) 2010-2023, rncbc aka Rui Nuno Capela. All rights reserved.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

 
*/

/********************************************************************************
** Form generated from reading UI file 'qmidinetOptionsForm.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QMIDINETOPTIONSFORM_H
#define UI_QMIDINETOPTIONSFORM_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_qmidinetOptionsForm
{
public:
    QHBoxLayout *hboxLayout;
    QVBoxLayout *vboxLayout;
    QGroupBox *MidiGroupBox;
    QGridLayout *gridLayout;
    QLabel *NumPortsTextLabel;
    QSpinBox *NumPortsSpinBox;
    QSpacerItem *spacerItem;
    QVBoxLayout *vboxLayout1;
    QCheckBox *AlsaMidiCheckBox;
    QCheckBox *JackMidiCheckBox;
    QSpacerItem *spacerItem1;
    QGroupBox *NetworkGroupBox;
    QGridLayout *gridLayout1;
    QLabel *InterfaceTextLabel;
    QComboBox *InterfaceComboBox;
    QSpacerItem *spacerItem2;
    QLabel *UdpAddrTextLabel;
    QComboBox *UdpAddrComboBox;
    QLabel *UdpPortTextLabel;
    QSpinBox *UdpPortSpinBox;
    QSpacerItem *spacerItem3;
    QDialogButtonBox *DialogButtonBox;

    void setupUi(QDialog *qmidinetOptionsForm)
    {
        if (qmidinetOptionsForm->objectName().isEmpty())
            qmidinetOptionsForm->setObjectName("qmidinetOptionsForm");
        qmidinetOptionsForm->resize(360, 240);
        const QIcon icon = QIcon(QString::fromUtf8(":/images/qmidinet.svg"));
        qmidinetOptionsForm->setWindowIcon(icon);
        hboxLayout = new QHBoxLayout(qmidinetOptionsForm);
        hboxLayout->setSpacing(4);
        hboxLayout->setContentsMargins(8, 8, 8, 8);
        hboxLayout->setObjectName("hboxLayout");
        vboxLayout = new QVBoxLayout();
        vboxLayout->setSpacing(4);
        vboxLayout->setObjectName("vboxLayout");
        MidiGroupBox = new QGroupBox(qmidinetOptionsForm);
        MidiGroupBox->setObjectName("MidiGroupBox");
        QFont font;
        font.setBold(true);
        MidiGroupBox->setFont(font);
        MidiGroupBox->setFlat(true);
        gridLayout = new QGridLayout(MidiGroupBox);
        gridLayout->setSpacing(4);
        gridLayout->setContentsMargins(8, 8, 8, 8);
        gridLayout->setObjectName("gridLayout");
        NumPortsTextLabel = new QLabel(MidiGroupBox);
        NumPortsTextLabel->setObjectName("NumPortsTextLabel");
        QFont font1;
        font1.setBold(false);
        NumPortsTextLabel->setFont(font1);

        gridLayout->addWidget(NumPortsTextLabel, 0, 0, 1, 1);

        NumPortsSpinBox = new QSpinBox(MidiGroupBox);
        NumPortsSpinBox->setObjectName("NumPortsSpinBox");
        NumPortsSpinBox->setFont(font1);
        NumPortsSpinBox->setAccelerated(true);
        NumPortsSpinBox->setMinimum(1);
        NumPortsSpinBox->setMaximum(32);
        NumPortsSpinBox->setValue(1);

        gridLayout->addWidget(NumPortsSpinBox, 0, 1, 1, 1);

        spacerItem = new QSpacerItem(20, 8, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem, 0, 2, 1, 1);

        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setSpacing(4);
        vboxLayout1->setObjectName("vboxLayout1");
        AlsaMidiCheckBox = new QCheckBox(MidiGroupBox);
        AlsaMidiCheckBox->setObjectName("AlsaMidiCheckBox");
        AlsaMidiCheckBox->setFont(font1);

        vboxLayout1->addWidget(AlsaMidiCheckBox);

        JackMidiCheckBox = new QCheckBox(MidiGroupBox);
        JackMidiCheckBox->setObjectName("JackMidiCheckBox");
        JackMidiCheckBox->setFont(font1);

        vboxLayout1->addWidget(JackMidiCheckBox);

        spacerItem1 = new QSpacerItem(20, 8, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout1->addItem(spacerItem1);


        gridLayout->addLayout(vboxLayout1, 1, 0, 1, 3);


        vboxLayout->addWidget(MidiGroupBox);

        NetworkGroupBox = new QGroupBox(qmidinetOptionsForm);
        NetworkGroupBox->setObjectName("NetworkGroupBox");
        NetworkGroupBox->setFont(font);
        NetworkGroupBox->setFlat(true);
        gridLayout1 = new QGridLayout(NetworkGroupBox);
        gridLayout1->setSpacing(4);
        gridLayout1->setContentsMargins(8, 8, 8, 8);
        gridLayout1->setObjectName("gridLayout1");
        InterfaceTextLabel = new QLabel(NetworkGroupBox);
        InterfaceTextLabel->setObjectName("InterfaceTextLabel");
        InterfaceTextLabel->setFont(font1);

        gridLayout1->addWidget(InterfaceTextLabel, 0, 0, 1, 1);

        InterfaceComboBox = new QComboBox(NetworkGroupBox);
        InterfaceComboBox->setObjectName("InterfaceComboBox");
        InterfaceComboBox->setFont(font1);
        InterfaceComboBox->setEditable(true);

        gridLayout1->addWidget(InterfaceComboBox, 0, 1, 1, 1);

        spacerItem2 = new QSpacerItem(20, 8, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem2, 0, 2, 1, 1);

        UdpAddrTextLabel = new QLabel(NetworkGroupBox);
        UdpAddrTextLabel->setObjectName("UdpAddrTextLabel");
        UdpAddrTextLabel->setFont(font1);

        gridLayout1->addWidget(UdpAddrTextLabel, 1, 0, 1, 1);

        UdpAddrComboBox = new QComboBox(NetworkGroupBox);
        UdpAddrComboBox->setObjectName("UdpAddrComboBox");
        UdpAddrComboBox->setFont(font1);
        UdpAddrComboBox->setEditable(true);

        gridLayout1->addWidget(UdpAddrComboBox, 1, 1, 1, 2);

        UdpPortTextLabel = new QLabel(NetworkGroupBox);
        UdpPortTextLabel->setObjectName("UdpPortTextLabel");
        UdpPortTextLabel->setFont(font1);

        gridLayout1->addWidget(UdpPortTextLabel, 2, 0, 1, 1);

        UdpPortSpinBox = new QSpinBox(NetworkGroupBox);
        UdpPortSpinBox->setObjectName("UdpPortSpinBox");
        UdpPortSpinBox->setFont(font1);
        UdpPortSpinBox->setAccelerated(true);
        UdpPortSpinBox->setMaximum(65535);

        gridLayout1->addWidget(UdpPortSpinBox, 2, 1, 1, 1);

        spacerItem3 = new QSpacerItem(20, 8, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem3, 2, 2, 1, 1);


        vboxLayout->addWidget(NetworkGroupBox);


        hboxLayout->addLayout(vboxLayout);

        DialogButtonBox = new QDialogButtonBox(qmidinetOptionsForm);
        DialogButtonBox->setObjectName("DialogButtonBox");
        DialogButtonBox->setOrientation(Qt::Vertical);
        DialogButtonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        hboxLayout->addWidget(DialogButtonBox);

#if QT_CONFIG(shortcut)
        NumPortsTextLabel->setBuddy(NumPortsSpinBox);
        InterfaceTextLabel->setBuddy(InterfaceComboBox);
        UdpAddrTextLabel->setBuddy(UdpAddrComboBox);
        UdpPortTextLabel->setBuddy(UdpPortSpinBox);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(NumPortsSpinBox, AlsaMidiCheckBox);
        QWidget::setTabOrder(AlsaMidiCheckBox, JackMidiCheckBox);
        QWidget::setTabOrder(JackMidiCheckBox, InterfaceComboBox);
        QWidget::setTabOrder(InterfaceComboBox, UdpAddrComboBox);
        QWidget::setTabOrder(UdpAddrComboBox, UdpPortSpinBox);
        QWidget::setTabOrder(UdpPortSpinBox, DialogButtonBox);

        retranslateUi(qmidinetOptionsForm);

        QMetaObject::connectSlotsByName(qmidinetOptionsForm);
    } // setupUi

    void retranslateUi(QDialog *qmidinetOptionsForm)
    {
        qmidinetOptionsForm->setWindowTitle(QCoreApplication::translate("qmidinetOptionsForm", "Options", nullptr));
        MidiGroupBox->setTitle(QCoreApplication::translate("qmidinetOptionsForm", "MIDI", nullptr));
        NumPortsTextLabel->setText(QCoreApplication::translate("qmidinetOptionsForm", "&Number of Ports:", nullptr));
        AlsaMidiCheckBox->setText(QCoreApplication::translate("qmidinetOptionsForm", "&ALSA", nullptr));
        JackMidiCheckBox->setText(QCoreApplication::translate("qmidinetOptionsForm", "&JACK", nullptr));
        NetworkGroupBox->setTitle(QCoreApplication::translate("qmidinetOptionsForm", "Network", nullptr));
        InterfaceTextLabel->setText(QCoreApplication::translate("qmidinetOptionsForm", "&Interface:", nullptr));
        UdpAddrTextLabel->setText(QCoreApplication::translate("qmidinetOptionsForm", "&UDP Address:", nullptr));
        UdpPortTextLabel->setText(QCoreApplication::translate("qmidinetOptionsForm", "UDP &Port:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class qmidinetOptionsForm: public Ui_qmidinetOptionsForm {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QMIDINETOPTIONSFORM_H
